function test_mexCASD_denoising(sigma_e_vec)
addpath(genpath('./'));

if nargin <  1
    sigma_e_vec=[5,10,15,20,25,50];
end

Input_dir = 'TestImages/';
Output_dir = 'Results/';
img_dir = dir(fullfile(Input_dir,'*.png'));

img_num = length(img_dir);

pSize = 8;
model_params.patch_size = pSize;
model_params.method = 'mexCASD';
model_params.dictionaryType = 'KSVD-Adaptive';


model_params.output = Output_dir;
model_params.cls_num = 30;
model_params.msgprt = 1;
model_params.beta = 0;


filename = sprintf('Results/mexCASD-%s %d%d%.0f.txt',date,hour(now),minute(now),second(now));
fid = fopen(filename,'w');

for i=1:length(sigma_e_vec)
    sigma_e=sigma_e_vec(length(sigma_e_vec) - i + 1);
    model_params.sigma_e = sigma_e;
    OutputDir = [Output_dir,num2str(sigma_e),'/'];
    if exist(OutputDir,'dir') == 0
        mkdir(OutputDir);
    end
    
    for j = 1:img_num,
        model_params.imgname = img_dir(j).name;
        im = imread(fullfile('TestImages', img_dir(j).name));
        
        noiseImg = double(im) + sigma_e*randn(size(im));
        imwrite(uint8(noiseImg),[OutputDir img_dir(j).name '[Noisy].png']);
        %         filename = fullfile(OutputDir, [img_dir(j).name, '[1-Noisy].png']);
        %         noiseImg = double(imread(filename));
        
        model_params.dictionary = DictTraining_KSVD(noiseImg, sigma_e, model_params.patch_size);
        
        %% CASD
        disp '=====================================================================';
        disp(model_params);
        fprintf(fid,'ImgName:%20s \t Method:%10s \t dictType:%s \t sigma_e:%d \t beta:%0.2f \r\n',...
            model_params.imgname,model_params.method,model_params.dictionaryType,model_params.sigma_e,model_params.beta);
        disp '================================CASD solving=====================================';
        tic;
        [I_casd,Q] = mexCASD_denoising(double(im),noiseImg,sigma_e,model_params);
        toc;
        I_casd = double2im(I_casd);
        imwrite(I_casd,[OutputDir, img_dir(j).name, '[mexCASD-',model_params.dictionaryType,',cls=',num2str(model_params.cls_num),',beta=',num2str(model_params.beta),'].png']);
        
        fprintf(    'Iter\tRMSE\tRMSE2\tCard\tORMSE\tPSNR\tSSIM\r\n');
        fprintf(fid,'Iter\tRMSE\tRMSE2\tCard\tORMSE\tPSNR\tSSIM\r\n');
        for t=1:size(Q,2)
            fprintf(    '%4d\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\r\n',Q(t).iter, Q(t).rmse_per_patch, Q(t).rmse_per_pixel, Q(t).card, Q(t).overlapRMSE, Q(t).psnr,Q(t).ssim);
            fprintf(fid,'%4d\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\r\n',Q(t).iter, Q(t).rmse_per_patch, Q(t).rmse_per_pixel, Q(t).card, Q(t).overlapRMSE, Q(t).psnr,Q(t).ssim);
        end
    end
end
%close(hh);
fclose(fid);
end
